==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/ts/Edit_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Preferenze Applicazione</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Preferenze Disegno</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Restart required</source>
        <translation>Riavvio richiesto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>Riavviare QCAD per
applicare le modifiche.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translatorcomment>--exact match--
--file: Translate_it.ts--
Punto di riferimento
Copia gli oggetti nel blocco note con un punto di riferimento</translatorcomment>
        <translation>Punto di riferimento</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Strumenti di modifica</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Mostra strumenti di editing</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+85"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <location line="-88"/>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Clear Search</source>
        <translation>Cancella ricerca</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Expand Tree</source>
        <translation>Espandi navigazione</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Crollo di navigazione</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Ripristina predefinita</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/ts/Edit_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Preferenze Applicazione</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Preferenze Disegno</translation>
    </message>
    <message>
        <location line="+300"/>
        <source>Apply preferences</source>
        <translation>Applica preferenze</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Restart required</source>
        <translation>Riavvio richiesto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>Riavviare QCAD per
applicare le modifiche.</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Defaults for </source>
        <translation>Predefiniti per</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>These are default preferences for new drawings.</source>
        <translation>Queste sono le preferenze predefinite per i nuovi disegni.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Preferences of the current drawing can be changed under&lt;br/&gt;&lt;i&gt;Edit &amp;gt; Drawing Preferences&lt;/i&gt;.</source>
        <translation>Preferenze del disegno corrente possono essere modificate in&lt;br/&gt;&lt;i&gt;Modifica &amp;gt; Preferenze disegno&lt;/i&gt;.</translation>
    </message>
    <message>
        <source>You are changing default preferences for new drawings.</source>
        <translation type="vanished">Queste sono le preferenze predefinite per i nuovi disegni.</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Changes will affect new drawings but NOT the current drawing.</source>
        <translation>Le modifiche avranno effetto nuovi disegni, ma non il disegno corrente.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translatorcomment>--exact match--
--file: Translate_it.ts--
Punto di riferimento
Copia gli oggetti nel blocco note con un punto di riferimento</translatorcomment>
        <translation>Punto di riferimento</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Strumenti di modifica</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Mostra strumenti di editing</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+71"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <location line="-74"/>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Clear Search</source>
        <translation type="vanished">Cancella ricerca</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Expand Tree</source>
        <translation>Espandi navigazione</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Crollo di navigazione</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Ripristina predefinita</translation>
    </message>
</context>
</TS>
